@@ -114,7 +114,7 @@ class NodeMetrix(object):
         bottom = [n for n in self.node.networks if n.xy.y > self.node.xy.y]
         bottom.sort(lambda a, b: cmp(a.xy.y, b.xy.y))
 
-        Connector = namedtuple('Connector', 'network line textbox jumps')
+        Connector = namedtuple('Connector', 'network line textbox')
 
         for networks in [above, bottom]:
             for network in networks:
@@ -137,7 +137,7 @@ class NodeMetrix(object):
                            x + width, y2]
                 line = [XY(x + dx, y1), XY(x + dx, y2)]
 
-                yield Connector(network, line, textbox, [])
+                yield Connector(network, line, textbox)
 
 
 class GroupMetrix(blockdiag.DiagramMetrix.NodeMetrix):
@@ -154,18 +154,18 @@ class GroupMetrix(blockdiag.DiagramMetrix.NodeMetrix):
 
     def groupLabelBox(self):
         box = super(GroupMetrix, self).groupLabelBox()
-        span = self.metrix.spanHeight / 2 - self.metrix.cellSize
-        box = (box[0], box[1] - span, box[2], box[3] - span)
+        span = self.metrix.cellSize
+        box = (box[0], box[1] + span, box[2], box[3] + span)
 
         if self.is_root_group:
-            width = box[2] - box[1]
-            box = (box[0] + width / 2, box[1], box[2], box[3])
+            width = (self.metrix.nodeWidth + self.metrix.spanWidth) / 2
+            box = (box[0] + width, box[1], box[2] + width, box[3])
 
         return box
 
     def marginBox(self):
-        box = super(GroupMetrix, self).marginBox()
-        margin_x = self.metrix.spanHeight / 2
+        box = super(GroupMetrix, self).box()
+        margin_x = self.metrix.spanHeight / 2 - self.metrix.cellSize
         margin_y = self.metrix.cellSize
         return (box[0] - margin_y, box[1] - margin_x,
                 box[2] + margin_y, box[3] + margin_x)
