@@ -40,6 +40,27 @@ class DiagramTreeBuilder:
                 msg = "DiagramNode %s does not belong to any networks"
                 raise RuntimeError(msg % msg.id)
 
+        # show networks including same nodes
+        for nw in self.diagram.networks:
+            if nw.hidden and len(nw.nodes) == 2:
+                nodes = nw.nodes
+                is_same = lambda x: set(nodes) & set(x.nodes) == set(nodes)
+                for n in self.diagram.networks:
+                    if n != nw and is_same(n):
+                        nw.hidden = False
+                        break
+
+        # show network for multiple peer networks from same node
+        nodes = []
+        for nw in self.diagram.networks:
+            if nw.hidden and len(nw.nodes) == 2:
+                nodes.append(nw.nodes[0])  # parent node (FROM node)
+
+        for node in [node for node in set(nodes) if nodes.count(node) > 1]:
+            for network in node.networks:
+                if len(network.nodes) == 2:
+                    network.hidden = False
+
         return self.diagram
 
     def instantiate(self, network, group, tree):
@@ -58,9 +79,11 @@ class DiagramTreeBuilder:
                 elif node.group is None:
                     node.group = self.diagram
 
-                if network not in node.networks:
-                    if network is not None:
+                if network is not None:
+                    if network not in node.networks:
                         node.networks.append(network)
+                    if node not in network.nodes:
+                        network.nodes.append(node)
                 if node not in self.diagram.nodes:
                     self.diagram.nodes.append(node)
 
@@ -105,11 +128,13 @@ class DiagramTreeBuilder:
 
                 if len(nodes[0].networks) == 0:
                     nw = Network.create_anonymous([nodes[0]])
-                    self.diagram.networks.append(nw)
+                    if nw:
+                        self.diagram.networks.append(nw)
 
                 for i in range(len(nodes) - 1):
                     nw = Network.create_anonymous(nodes[i:i + 2], stmt.attrs)
-                    self.diagram.networks.append(nw)
+                    if nw:
+                        self.diagram.networks.append(nw)
 
             elif isinstance(stmt, diagparser.DefAttrs):
                 self.diagram.set_attributes(stmt.attrs)
