@@ -174,6 +174,24 @@ def test_peer_network3_diagram():
         assert node.xy == assert_pos[node.id]
 
 
+def test_peer_network4_diagram():
+    screen = __build_diagram('peer_network4.diag')
+
+    assert_pos = {'A': (0, 0), 'B': (1, 1), 'C': (1, 2)}
+    for node in screen.nodes:
+        print assert_pos[node.id], node.xy
+        assert node.xy == assert_pos[node.id]
+
+
+def test_peer_network5_diagram():
+    screen = __build_diagram('peer_network5.diag')
+
+    assert_pos = {'A': (0, 0), 'B': (1, 0), 'C': (2, 0), 'D': (2, 1)}
+    for node in screen.nodes:
+        print assert_pos[node.id], node.xy
+        assert node.xy == assert_pos[node.id]
+
+
 def test_peer_network_branched_diagram():
     screen = __build_diagram('peer_network_branched.diag')
 
@@ -181,3 +199,12 @@ def test_peer_network_branched_diagram():
     for node in screen.nodes:
         print assert_pos[node.id], node.xy
         assert node.xy == assert_pos[node.id]
+
+
+def test_same_peer_network_diagram():
+    screen = __build_diagram('same_peer_network.diag')
+
+    assert_pos = {'A': (0, 0), 'B': (0, 1), 'C': (1, 2), 'D': (0, 3)}
+    for node in screen.nodes:
+        print assert_pos[node.id], node.xy
+        assert node.xy == assert_pos[node.id]
